@@ -257,6 +257,8 @@ class WorkingRepo(git.Repo):
         if self.patch_repo_path:
             raise exc.AlreadyLinkedToPatchRepo
 
+        patch_repo_path = os.path.abspath(os.path.expanduser(patch_repo_path))
+
         self.config('add', config_key='ply.patchrepo',
                     config_value=patch_repo_path)
 
@@ -275,7 +277,7 @@ class WorkingRepo(git.Repo):
         """
         patch_name = self._resolve_conflict('skip')
         self.patch_repo.remove_patches([patch_name])
-        self.restore()  # Apply remaining patches
+        self.restore(fetch_remotes=False)  # Apply remaining patches
 
     def resolve(self):
         """Resolves a commit and refreshes the affected patch in the
@@ -294,7 +296,7 @@ class WorkingRepo(git.Repo):
             [patch_name], source_paths, parent_patch_name=parent_patch_name)
 
         self._add_patch_annotation(patch_name)
-        self.restore()  # Apply remaining patches
+        self.restore(fetch_remotes=False)  # Apply remaining patches
 
     @property
     def _restore_stats_path(self):
@@ -329,7 +331,8 @@ class WorkingRepo(git.Repo):
 
         return updated, removed
 
-    def restore(self, three_way_merge=True, commit_msg=None):
+    def restore(self, three_way_merge=True, commit_msg=None,
+                fetch_remotes=True):
         """Applies a series of patches to the working repo's current
         branch.
         """
@@ -341,12 +344,13 @@ class WorkingRepo(git.Repo):
         # been successfully applied, skipped, or we've aborted the restore.
         #
         #####################################################################
+        if self.rebase_in_progress():
+            raise exc.RestoreInProgress
+
         if self.uncommitted_changes():
             raise exc.UncommittedChanges
 
-        # FIXME: this should probably not be done in the reentrant section and
-        # instead should be done one time, on initializing the restore
-        if self.fetch_remotes:
+        if fetch_remotes and self.fetch_remotes:
             self.fetch(all=True)
 
         applied = set(pn for _, pn in self._applied_patches())
@@ -512,7 +516,7 @@ class WorkingRepo(git.Repo):
         # We have to commit to the patch-repo AFTER rolling-back and
         # reapplying so that we have the patch-annotations necessary to figure
         # out the correct Ply-Based-On annotation in the patch-repo.
-        self.restore(commit_msg=commit_msg)
+        self.restore(commit_msg=commit_msg, fetch_remotes=False)
 
     @property
     def status(self):
@@ -611,7 +615,9 @@ class PatchRepo(git.Repo):
                 # For simplicity, we regenerate all patches, however some will
                 # be the same, so perform a file compare so we keep accurate
                 # counts of which were truly updatd
-                if not filecmp.cmp(source_path, dest_path):
+                if filecmp.cmp(source_path, dest_path):
+                    os.unlink(source_path)
+                else:
                     updated.add(patch_name)
                     shutil.move(source_path, dest_path)
             else:
