@@ -60,6 +60,7 @@ class Repo(object):
         stdout, stderr = proc.communicate()
 
         if not quiet:
+            print stderr
             print stdout
 
         if proc.returncode == 0:
@@ -253,3 +254,6 @@ class Repo(object):
 
     def uncommitted_changes(self):
         return len(self.diff_index('HEAD')) != 0
+
+    def rebase_in_progress(self):
+        return os.path.exists(os.path.join(self.path, '.git', 'rebase-apply'))
